<div align="center"> 
    
# Stone-Color
[Installation](#installation) - [Quick usage](#quick-usage) - [Docs](https://stone-color.readthedocs.io/en/latest/) - [Contributors](#contributors)

<img src=".img/logo.png" width=80%>
</div>

# Installation

You can install **Stone-color** using the *package manager "pip"* which installs the *package from "PyPI"*

```
pip install stone-color
```

To update the package you can add `-U` to the command line

# Quick usage

```python
from stone_color.messages import printf

printf("Hello {#b71e1b}world{#reset}")
```

# [Docs](https://stone-color.readthedocs.io/en/latest/)

Go to [docs](https://stone-color.readthedocs.io/en/latest/)

# Contributors

<a href="https://github.com/aniko33/stone-color/graphs/contributors">
    <img src="https://contributors-img.web.app/image?repo=aniko33/stone-color">
</a>
